summaryrefslogtreecommitdiffstats
path: root/hl
diff options
context:
space:
mode:
authorElena Pourmal <epourmal@hdfgroup.org>2009-08-04 22:07:49 (GMT)
committerElena Pourmal <epourmal@hdfgroup.org>2009-08-04 22:07:49 (GMT)
commit62a0855dfc95cf21472021a90ee92a9a8a123c25 (patch)
treef667e15cfe829bbb52559e7d6608adc9d9c7472f /hl
parent98682148dd539ced810ba7d168bf38233d0ce32a (diff)
downloadhdf5-62a0855dfc95cf21472021a90ee92a9a8a123c25.zip
hdf5-62a0855dfc95cf21472021a90ee92a9a8a123c25.tar.gz
hdf5-62a0855dfc95cf21472021a90ee92a9a8a123c25.tar.bz2
[svn-r17301] Maintenance: I forgot to check in the updated test file, therefore
daily tests failed. Checking in the fix. Platforms tested: jam
Diffstat (limited to 'hl')
-rw-r--r--hl/test/test_regref_hyper.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/hl/test/test_regref_hyper.c b/hl/test/test_regref_hyper.c
index 9075757..5e7e6dd 100644
--- a/hl/test/test_regref_hyper.c
+++ b/hl/test/test_regref_hyper.c
@@ -27,7 +27,7 @@
#define dsetnamer "R1"
/* used by H5Lvisit_by_name */
-static size_t _regref_to_all_start; /* starting index counter for placing data into 1D array, used by H5LRcreate_regref_to_all */
+static size_t _regref_to_all_start; /* starting index counter for placing data into 1D array, used by H5LRcreate_ref_to_all */
static H5R_type_t _regref_type; /* type of data to create region references for */
@@ -775,12 +775,12 @@ static int test_regref_hyper( void )
/*-------------------------------------------------------------------------
- * Testing H5LRcreate_regref_to_all
+ * Testing H5LRcreate_ref_to_all
*-------------------------------------------------------------------------
*/
- TESTING("H5LRcreate_regref_to_all Region Reference Datatset");
- status = H5LRcreate_regref_to_all(file_id, "/","/RegRef", H5_INDEX_NAME, H5_ITER_INC, H5R_DATASET_REGION);
+ TESTING("H5LRcreate_ref_to_all Region Reference Datatset");
+ status = H5LRcreate_ref_to_all(file_id, "/","/RegRef", H5_INDEX_NAME, H5_ITER_INC, H5R_DATASET_REGION);
if(status < 0) goto out;
@@ -794,8 +794,8 @@ static int test_regref_hyper( void )
PASSED();
- TESTING("H5LRcreate_regref_to_all Region Reference Object");
- status = H5LRcreate_regref_to_all(file_id, "/","/ObjRef", H5_INDEX_NAME, H5_ITER_INC, H5R_OBJECT);
+ TESTING("H5LRcreate_ref_to_all Region Reference Object");
+ status = H5LRcreate_ref_to_all(file_id, "/","/ObjRef", H5_INDEX_NAME, H5_ITER_INC, H5R_OBJECT);
if(status < 0) goto out;